==> haskell-loch-th-0.2.2-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-loch-th.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: loch-th
version: 0.2.2
id: loch-th-0.2.2-J0bTgsUMLFvDsTVuSTScnJ
key: loch-th-0.2.2-J0bTgsUMLFvDsTVuSTScnJ
license: BSD3
maintainer: tomi@nomi.cz
homepage: https://github.com/liskin/loch-th
synopsis: Support for precise error locations in source files (Template Haskell version)
description:
    This module provides a Template Haskell based mechanism to
    tag failures with the location of the failure call. The
    location message includes the file name, line and column
    numbers.
category: Development
author: Tomas Janousek
exposed: True
indefinite: False
exposed-modules:
    Debug.Trace.LocationTH
abi: 6ebcb425d9bd801b8232e32e531b7de0
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/loch-th-0.2.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/loch-th-0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/loch-th-0.2.2
hs-libraries: HSloch-th-0.2.2-J0bTgsUMLFvDsTVuSTScnJ
depends:
    base-4.10.1.0 pretty-1.1.3.3 template-haskell-2.12.0.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             pretty-1.1.3.3=229bcf5342145ac1755207fe83d29780
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
haddock-interfaces: /usr/share/doc/haskell-loch-th/html/loch-th.haddock
haddock-html: /usr/share/doc/haskell-loch-th/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-loch-th-0.2.2-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-loch-th.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: loch-th
version: 0.2.2
id: loch-th-0.2.2-5Eq2dK8L8YJJWK4HNR9w70
key: loch-th-0.2.2-5Eq2dK8L8YJJWK4HNR9w70
license: BSD-3-Clause
maintainer: tomi@nomi.cz
author: Tomas Janousek
homepage: https://github.com/liskin/loch-th
synopsis: Support for precise error locations in source files (Template Haskell version)
description:
    This module provides a Template Haskell based mechanism to
    tag failures with the location of the failure call. The
    location message includes the file name, line and column
    numbers.
category: Development
abi: 00fd0dc72b72ed83b5d37907b4600d8e
exposed: True
exposed-modules:
    Debug.Trace.LocationTH
import-dirs: /usr/lib/ghc-8.4.3/site-local/loch-th-0.2.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/loch-th-0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/loch-th-0.2.2
hs-libraries: HSloch-th-0.2.2-5Eq2dK8L8YJJWK4HNR9w70
depends:
    base-4.11.1.0 pretty-1.1.3.6 template-haskell-2.13.0.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             pretty-1.1.3.6=3c31686bd534e1773b954ae82713db97
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
haddock-interfaces: /usr/share/doc/haskell-loch-th/html/loch-th.haddock
haddock-html: /usr/share/doc/haskell-loch-th/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
